@@ -104,7 +104,7 @@ class FamilyParser(object):
         
         for line in family_file:
             if line.startswith('#'):
-                self.header = line[1:].split('\t')
+                self.header = line[1:].rstrip().split('\t')
             elif not all(c in whitespace for c in line.rstrip()):
                 line = line.rstrip().split('\t')
                 if len(line) != len(self.header):
@@ -210,7 +210,7 @@ class FamilyParser(object):
                         }
             for individual_id in self.families[family_id].individuals:
                 individual = {'individual_id': individual_id,
-                                'sex:': self.families[family_id].individuals[individual_id].sex,
+                                'sex': self.families[family_id].individuals[individual_id].sex,
                                 'phenotype': self.families[family_id].individuals[individual_id].phenotype,
                                 'mother': self.families[family_id].individuals[individual_id].mother,
                                 'father': self.families[family_id].individuals[individual_id].father
